@@ -14,7 +14,7 @@ func Nushell(completers []string) string {
 
 let carapace_completer = {|spans|
   # if the current command is an alias, get it's expansion
-  let expanded_alias = (scope aliases | where name == $spans.0 | get -i 0 | get -i expansion)
+  let expanded_alias = (scope aliases | where name == $spans.0 | $in.0?.expansion?)
 
   # overwrite
   let spans = (if $expanded_alias != null  {
@@ -32,7 +32,8 @@ mut current = (($env | default {} config).config | default {} completions)
 $current.completions = ($current.completions | default {} external)
 $current.completions.external = ($current.completions.external
 | default true enable
-| default { $carapace_completer } completer)
+# backwards compatible workaround for default, see nushell #15654
+| upsert completer { if $in == null { $carapace_completer } else { $in } })
 
 $env.config = $current
     `
