@@ -16,7 +16,7 @@ func init() {
 	carapace.Gen(git_fetchCmd).Standalone()
 
 	git_fetchCmd.Flags().Bool("all-remotes", false, "Fetch from all remotes")
-	git_fetchCmd.Flags().StringSlice("branch", nil, "Fetch only some of the branches")
+	git_fetchCmd.Flags().StringSliceP("branch", "b", nil, "Fetch only some of the branches")
 	git_fetchCmd.Flags().BoolP("help", "h", false, "Print help (see more with '--help')")
 	git_fetchCmd.Flags().StringSlice("remote", []string{"origin"}, "The remote to fetch from (only named remotes are supported, can be repeated)")
 	gitCmd.AddCommand(git_fetchCmd)
